@@ -41,6 +41,7 @@ lazy_static! {
 }
 
 #[derive(Clone, Debug, Display, Api)]
+#[cfg_attr(feature = "strict_encoding", derive(NetworkEncode, NetworkDecode))]
 #[api(encoding = "lightning")]
 #[non_exhaustive]
 #[display(inner)]
@@ -181,29 +182,3 @@ impl LightningDecode for Messages {
         Ok(message.clone())
     }
 }
-
-#[cfg(feature = "strict_encoding")]
-impl strict_encoding::StrictEncode for Messages {
-    fn strict_encode<E: io::Write>(
-        &self,
-        e: E,
-    ) -> Result<usize, strict_encoding::Error> {
-        Payload::from(self.clone()).strict_encode(e)
-    }
-}
-
-#[cfg(feature = "strict_encoding")]
-impl strict_encoding::StrictDecode for Messages {
-    fn strict_decode<D: io::Read>(
-        d: D,
-    ) -> Result<Self, strict_encoding::Error> {
-        let message = &*LNP2P_LEGACY_UNMARSHALLER
-            .unmarshall(&Vec::<u8>::strict_decode(d)?)
-            .map_err(|_| {
-                strict_encoding::Error::DataIntegrityError(s!(
-                    "can't unmarshall legacy LNP2P message"
-                ))
-            })?;
-        Ok(message.clone())
-    }
-}
